@@ -15,7 +15,7 @@ except:
 # In[3]:
 
 
-version = '0.49'
+version = '0.51'
 
 import re
 import tempfile
@@ -220,9 +220,12 @@ def txtread(path):
             return f.read()
 
 def txtwrite(path, txt):
-    os.makedirs(os.path.dirname(path), exist_ok=True)
-    with open(path, 'w') as f:
-        return f.write(txt)
+    if 'gs://' in path:
+        gsTxtread(path, txt)
+    else:
+        os.makedirs(os.path.dirname(path), exist_ok=True)
+        with open(path, 'w') as f:
+            return f.write(txt)
 
 
 # In[22]:
@@ -352,7 +355,7 @@ def gsTxtread(path):
 
 def gsImwrite(path, img):
     blob = _gsBlob(path)
-    _, encimg = cv2.imencode('.png', img)
+    _, encimg = cv2.imencode('.png', img[:, :, [2, 1, 0]])
     blob.upload_from_string(encimg.tobytes())
 
 
@@ -362,7 +365,7 @@ def gsImwrite(path, img):
 def gsImread(path):
     blob = _gsBlob(path)
     raw = np.asarray(bytearray(blob.download_as_string()), dtype="uint8")
-    return cv2.imdecode(raw, 1)
+    return cv2.imdecode(raw, 1)[:, :, [2, 1, 0]]
 
 
 # # Images
@@ -1048,7 +1051,7 @@ lx/__init__.py
 """
 
 
-# In[90]:
+# In[91]:
 
 
 if is_testing():
@@ -1065,15 +1068,3 @@ if is_testing():
             #print(shell("cd {d} && git status && git config user.name 'lx' && git config user.email 'lx' && git commit -a -m 'Add' && git log && git push && python setup.py sdist && twine upload dist/* --verbose".format(d=d)))
             print(shell("cd {d} && python3 setup.py sdist && twine upload dist/* --verbose".format(d=d)))
 
-
-# In[ ]:
-
-
-
-
-
-# In[ ]:
-
-
-
-
